package ru.ulstu.fc.rule.controller;

import jakarta.validation.Valid;
import org.springframework.stereotype.Controller;
import org.springframework.ui.Model;
import org.springframework.validation.BindingResult;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestMapping;
import ru.ulstu.fc.rule.model.FuzzyTermForm;
import ru.ulstu.fc.rule.service.FuzzyTermService;

@Controller
@RequestMapping("fuzzyTerm")
public class FuzzyTermController {
    private final FuzzyTermService fuzzyTermService;

    public FuzzyTermController(FuzzyTermService fuzzyTermService) {
        this.fuzzyTermService = fuzzyTermService;
    }

    @GetMapping("/edit/{projectId}/{variableId}/{fuzzyTermId}")
    public String edit(@PathVariable(value = "projectId") Integer projectId,
                       @PathVariable(value = "variableId") Integer variableId,
                       @PathVariable(value = "fuzzyTermId") Integer fuzzyTermId, Model model) {
        model.addAttribute("projectId", projectId);
        model.addAttribute("variableId", variableId);
        model.addAttribute("fuzzyTermForm",
                (fuzzyTermId == null || fuzzyTermId == 0)
                        ? new FuzzyTermForm(fuzzyTermId, projectId, variableId)
                        : new FuzzyTermForm(fuzzyTermId, projectId, variableId, fuzzyTermService.getById(fuzzyTermId)));
        model.addAttribute("fuzzyTerms", fuzzyTermService.getByVariableId(variableId));
        return "fuzzyTerm/edit";
    }

    @PostMapping(value = "save", params = "save")
    public String save(@Valid FuzzyTermForm fuzzyTermForm, BindingResult result, Model model) {
        if (result.hasErrors()) {
            model.addAttribute("projectId", fuzzyTermForm.getProjectId());
            return "fuzzyTerm/edit";
        }
        fuzzyTermService.save(fuzzyTermForm);
        return "redirect:/variable/edit/" + fuzzyTermForm.getProjectId() + "/" + fuzzyTermForm.getVariableId();
    }

    @PostMapping(value = "save", params = "delete")
    public String delete(FuzzyTermForm fuzzyTermForm) {
        if (fuzzyTermForm != null && fuzzyTermForm.getId() != null) {
            fuzzyTermService.delete(fuzzyTermForm);
        }
        return "redirect:/variable/edit/" + fuzzyTermForm.getProjectId() + "/" + fuzzyTermForm.getVariableId();
    }
}
