package ru.ulstu.fc.rule.controller;

import jakarta.validation.Valid;
import org.springframework.stereotype.Controller;
import org.springframework.ui.Model;
import org.springframework.validation.BindingResult;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestMapping;
import ru.ulstu.fc.rule.model.VariableForm;
import ru.ulstu.fc.rule.service.FuzzyTermService;
import ru.ulstu.fc.rule.service.VariableService;

@Controller
@RequestMapping("variable")
public class VariableController {
    private final VariableService variableService;
    private final FuzzyTermService termService;

    public VariableController(VariableService variableService,
                              FuzzyTermService termService) {
        this.variableService = variableService;
        this.termService = termService;
    }

    @GetMapping("/edit/{projectId}/{variableId}")
    public String edit(@PathVariable(value = "projectId") Integer projectId,
                       @PathVariable(value = "variableId") Integer variableId, Model model) {
        model.addAttribute("projectId", projectId);
        model.addAttribute("variableForm",
                (variableId == null || variableId == 0)
                        ? new VariableForm(variableId, projectId)
                        : new VariableForm(variableId, variableService.getById(variableId)));
        model.addAttribute("fuzzyTerms", termService.getByVariableId(variableId));
        return "variable/edit";
    }

    @PostMapping(value = "save", params = "save")
    public String save(@Valid VariableForm variableForm, BindingResult result, Model model) {
        if (result.hasErrors()) {
            model.addAttribute("projectId", variableForm.getProjectId());
            return "variable/edit";
        }
        variableService.save(variableForm);
        return "redirect:/project/edit/" + variableForm.getProjectId();
    }

    @PostMapping(value = "save", params = "delete")
    public String delete(VariableForm variableForm) {
        if (variableForm != null && variableForm.getId() != null) {
            variableService.delete(variableForm);
        }
        return "redirect:/project/edit/" + variableForm.getProjectId();
    }
}
