package ru.ulstu.fc.rule.model;

import jakarta.persistence.CascadeType;
import jakarta.persistence.Entity;
import jakarta.persistence.FetchType;
import jakarta.persistence.JoinColumn;
import jakarta.persistence.ManyToOne;
import jakarta.persistence.OneToMany;
import jakarta.validation.constraints.NotNull;
import jakarta.validation.constraints.Size;
import ru.ulstu.fc.core.model.BaseEntity;
import ru.ulstu.fc.project.model.Project;

import java.util.ArrayList;
import java.util.List;

@Entity
public class Variable extends BaseEntity {
    @Size(min = 3, max = 250, message = "Длина должна быть от 3 до 250")
    private String name;

    @ManyToOne
    @NotNull
    private Project project;

    private boolean input = true;

    @OneToMany(cascade = CascadeType.ALL, fetch = FetchType.LAZY)
    @JoinColumn(name = "variable_id")
    private List<FuzzyTerm> fuzzyTerms = new ArrayList<>();

    public Variable() {
    }

    public Variable(String name) {
        this.name = name;
    }

    public Variable(String name, List<FuzzyTerm> fuzzyTerms) {
        this.name = name;
        this.fuzzyTerms = fuzzyTerms;
    }

    public String getName() {
        return name;
    }

    public void setName(String name) {
        this.name = name;
    }

    public List<FuzzyTerm> getFuzzyTerms() {
        return fuzzyTerms;
    }

    public void setFuzzyTerms(List<FuzzyTerm> fuzzyTerms) {
        this.fuzzyTerms = fuzzyTerms;
    }

    public Project getProject() {
        return project;
    }

    public void setProject(Project project) {
        this.project = project;
    }

    public boolean isInput() {
        return input;
    }

    public void setInput(boolean input) {
        this.input = input;
    }
}