package ru.ulstu.fc.rule.service;

import com.fuzzylite.Engine;
import com.fuzzylite.rule.Rule;
import org.springframework.stereotype.Service;

import java.util.List;
import java.util.stream.Collectors;

@Service
public class FuzzyRuleParseService {
    private final static String RU_IF_STATEMENT = "если";
    private final static String ENG_IF_STATEMENT = "if";
    private final static String RU_THEN_STATEMENT = "то";
    private final static String ENG_THEN_STATEMENT = "then";
    private final static String RU_AND_STATEMENT = "и";
    private final static String ENG_AND_STATEMENT = "and";
    private final static String RU_IS_STATEMENT = "является";
    private final static String RU_EQ_STATEMENT = "равно";
    private final static String ENG_IS_STATEMENT = "is";

    private final Engine fuzzyEngine;

    public FuzzyRuleParseService(Engine fuzzyEngine) {
        this.fuzzyEngine = fuzzyEngine;
    }

    public List<Rule> parseRules(List<String> stringRules) {
        return stringRules
                .stream()
                .map(s -> Rule.parse(replaceEnglishKeywords(s), fuzzyEngine))
                .collect(Collectors.toList());
    }

    private String replaceEnglishKeywords(String stringRule) {
        stringRule = stringRule.toLowerCase();
        return stringRule
                .replaceFirst(RU_IF_STATEMENT, ENG_IF_STATEMENT)
                .replaceFirst(RU_AND_STATEMENT, ENG_AND_STATEMENT)
                .replaceFirst(RU_IS_STATEMENT, ENG_IS_STATEMENT)
                .replaceFirst(RU_EQ_STATEMENT, ENG_IS_STATEMENT)
                .replaceAll(RU_THEN_STATEMENT, ENG_THEN_STATEMENT);
    }
}
