package ru.ulstu.fc.rule.service;

import org.springframework.stereotype.Service;
import ru.ulstu.fc.rule.model.FuzzyTerm;
import ru.ulstu.fc.rule.model.FuzzyTermForm;
import ru.ulstu.fc.rule.repository.FuzzyTermRepository;

import java.util.Collections;
import java.util.List;

@Service
public class FuzzyTermService {
    private final FuzzyTermRepository fuzzyTermRepository;
    private final VariableService variableService;

    public FuzzyTermService(FuzzyTermRepository fuzzyTermRepository,
                            VariableService variableService) {
        this.fuzzyTermRepository = fuzzyTermRepository;
        this.variableService = variableService;
    }

    public FuzzyTerm getById(Integer id) {
        return fuzzyTermRepository
                .findById(id)
                .orElseThrow(() -> new RuntimeException("Term not found by id"));
    }

    public FuzzyTerm save(FuzzyTermForm fuzzyTermForm) {
        FuzzyTerm term;
        if (fuzzyTermForm.getId() == null || fuzzyTermForm.getId() == 0) {
            term = new FuzzyTerm();
        } else {
            term = getById(fuzzyTermForm.getId());
        }
        term.setDescription(fuzzyTermForm.getDescription());
        term.setCrispValue(fuzzyTermForm.getCrispValue());
        FuzzyTerm ft = fuzzyTermRepository.save(term);
        if (fuzzyTermForm.getId() == null || fuzzyTermForm.getId() == 0) {
            variableService.addFuzzyTerm(fuzzyTermForm.getVariableId(), ft);
        }
        return ft;

    }

    public void delete(FuzzyTermForm fuzzyTermForm) {
        getById(fuzzyTermForm.getId());
        fuzzyTermRepository.deleteById(fuzzyTermForm.getId());
    }

    public List<FuzzyTerm> getByVariableId(Integer variableId) {
        if (variableId == null || variableId == 0) {
            return Collections.emptyList();
        }
        return variableService.getById(variableId).getFuzzyTerms();
    }
}
