package ru.ulstu.fc.rule.service;

import org.springframework.stereotype.Service;
import ru.ulstu.fc.project.service.ProjectService;
import ru.ulstu.fc.rule.model.FuzzyTerm;
import ru.ulstu.fc.rule.model.Variable;
import ru.ulstu.fc.rule.model.VariableForm;
import ru.ulstu.fc.rule.repository.VariableRepository;

@Service
public class VariableService {
    private final VariableRepository variableRepository;
    private final ProjectService projectService;

    public VariableService(VariableRepository variableRepository, ProjectService projectService) {
        this.variableRepository = variableRepository;
        this.projectService = projectService;
    }

    public Variable getById(Integer id) {
        return variableRepository
                .findById(id)
                .orElseThrow(() -> new RuntimeException("Variable not found by id"));
    }

    public Variable save(VariableForm variableForm) {
        Variable variable;
        if (variableForm.getId() == null || variableForm.getId() == 0) {
            variable = new Variable();
        } else {
            variable = getById(variableForm.getId());
        }
        variable.setProject(projectService.getById(variableForm.getProjectId()));
        variable.setName(variableForm.getName());
        variable.setInput(variableForm.isInput());
        return variableRepository.save(variable);
    }

    public void delete(VariableForm ruleForm) {
        getById(ruleForm.getId());
        variableRepository.deleteById(ruleForm.getId());
    }

    public void addFuzzyTerm(Integer variableId, FuzzyTerm ft) {
        Variable var = getById(variableId);
        var.getFuzzyTerms().add(ft);
        variableRepository.save(var);
    }
}
